@@ -77,31 +77,42 @@ callback_model_checkpoint <- function(filepath, monitor = "val_loss", verbose =
     mode = match.arg(mode)
   )
   
-  if (tensorflow::tf_version() < "1.14") {
+  if (is_tensorflow_implementation()) {
+    if (tensorflow::tf_version() < "1.14") {
+      
+      if (!is.null(save_freq))
+        warning(
+          "The save_freq argument is only used by TensorFlow >= 1.14. ",
+          "Update TensorFlow or use save_freq = NULL"
+        )
+      
+      if (is.null(period))
+        period <- 1L
+      
+      args$period <- as.integer(period)
+    } else {
+      
+      if (!is.null(period))
+        warning(
+          "The period argument is deprecated since TF v1.14 and will be ignored. ",
+          "Use save_freq instead."
+        )
+      
+      # save_freq can be a string or an integer
+      if (is.character(save_freq))
+        args$save_freq <- save_freq
+      else 
+        args$save_freq <- as_nullable_integer(save_freq)
+    }
+  } else if (is_backend("plaidml")) {
     
     if (!is.null(save_freq))
-      warning(
-        "The save_freq argument is only used by TensorFlow >= 1.14. ",
-        "Update TensorFlow or use save_freq = NULL"
-      )
+      warning("`save_freq` is ignored in plaidml. Use the `period` argument.")
     
-    if (is.null(period))
+    if (is.null(save_freq) && is.null(period))
       period <- 1L
     
     args$period <- as.integer(period)
-  } else {
-    
-    if (!is.null(period))
-      warning(
-      "The period argument is deprecated since TF v1.14 and will be ignored. ",
-      "Use save_freq instead."
-      )
-    
-    # save_freq can be a string or an integer
-    if (is.character(save_freq))
-      args$save_freq <- save_freq
-    else 
-      args$save_freq <- as.integer(save_freq)
   }
   
   do.call(keras$callbacks$ModelCheckpoint, args)
@@ -616,7 +627,12 @@ normalize_callbacks_with_metrics <- function(view_metrics, callbacks) {
     callbacks <- list(callbacks)
   
   # always include the metrics callback
-  callbacks <- append(callbacks, KerasMetricsCallback$new(view_metrics))  
+  if (tensorflow::tf_version() >= "2.2.0")
+    metrics_callback <- KerasMetricsCallbackV2$new(view_metrics)
+  else
+    metrics_callback <- KerasMetricsCallback$new(view_metrics)
+  
+  callbacks <- append(callbacks, metrics_callback)  
  
   normalize_callbacks(callbacks) 
 }
@@ -706,11 +722,11 @@ normalize_callbacks <- function(callbacks) {
       )
       
       # on_batch_* -> on_train_batch_*
-      if (!identical(callback$on_batch_begin, empty_fun)) {
+      if (!isTRUE(all.equal(callback$on_batch_begin, empty_fun))) {
         args$r_on_train_batch_begin <- callback$on_batch_begin
       }
       
-      if (!identical(callback$on_batch_end, empty_fun)) {
+      if (!isTRUE(all.equal(callback$on_batch_end, empty_fun))) {
         args$r_on_train_batch_end <- callback$on_batch_end
       }
       
