@@ -1,17 +1,18 @@
 
 import os
 
-if (os.getenv('KERAS_IMPLEMENTATION', 'keras') == 'tensorflow'):
-  from tensorflow.python.keras.engine import Layer
+if (os.getenv('KERAS_IMPLEMENTATION', 'tensorflow') == 'keras'):
+  from keras.engine.topology import Layer
+  def shape_filter(shape):
+    return shape
+else:
+  from tensorflow.keras.layers import Layer
   def shape_filter(shape):
     if not isinstance(shape, list):
       return shape.as_list()
     else:
       return shape
-else:
-  from keras.engine.topology import Layer
-  def shape_filter(shape):
-    return shape
+  
 
 class RLayer(Layer):
 
