@@ -2,15 +2,14 @@
 
 import os
 
-if (os.getenv('KERAS_IMPLEMENTATION', 'keras') == 'tensorflow'):
+if (os.getenv('KERAS_IMPLEMENTATION', 'tensorflow') == 'keras'):
+  from keras.engine import Model
+else:
   try:
     from tensorflow.python.keras.engine import Model
   except:
     from tensorflow.python.keras.engine.training import Model
-else:
-  from keras.engine import Model
- 
- 
+
 class RModel(Model):
 
   def __init__(self, name = None):
