@@ -70,6 +70,9 @@ test_succeeds("image data generator can be used for training", {
 
 test_succeeds("R function can be used as custom generator", {
  
+  if (tensorflow::tf_version() >= "2.1")
+    skip("TODO: R based generators are not working with TF >= 2.1")
+  
   # create model
   library(keras)
   model <- keras_model_sequential()
@@ -121,6 +124,9 @@ test_succeeds("R function can be used as custom generator", {
 
 test_succeeds("R function can be used as custom generator with multiple inputs", {
   
+  if (tensorflow::tf_version() >= "2.1")
+    skip("TODO: R based generators are not working with TF >= 2.1")
+  
   input1 <- layer_input(shape = 1)
   input2 <- layer_input(shape = 1)
   
@@ -142,6 +148,9 @@ test_succeeds("R function can be used as custom generator with multiple inputs",
 
 test_succeeds("Fixed validation_data instead of generator with fit_generator", {
 
+  if (tensorflow::tf_version() >= "2.1")
+    skip("TODO: R based generators are not working with TF >= 2.1")
+  
   input1 <- layer_input(shape = 1)
   input2 <- layer_input(shape = 1)
   
@@ -165,6 +174,9 @@ test_succeeds("Fixed validation_data instead of generator with fit_generator", {
 
 test_succeeds("Can use a custom preprocessing function in image_data_generator", {
   
+  if (tensorflow::tf_version() >= "2.1")
+    skip("TODO: R based generators are not working with TF >= 2.1")
+  
   img_gen <- image_data_generator(preprocessing_function = function(x) x/255)
   
   mnist <- dataset_mnist()
